@@ -7,7 +7,7 @@
  * not enough to hold len bytes, stralloc_ready allocates at least len
  * bytes of space, copies the old string into the new space, frees the
  * old space, and returns 1. Note that this changes sa.s. */
-int stralloc_ready(stralloc *sa,unsigned int len) {
+int stralloc_ready(stralloc *sa,unsigned long int len) {
   register int wanted=len+(len>>3)+30; /* heuristic from djb */
   if (!sa->s || sa->a<len) {
     register char* tmp;
