@@ -26,6 +26,9 @@
      __asm__ __volatile__ ("rdtsc" : "=a" (low) : : "edx")
 
 int64 writecb(int64 fd,const void* buf,uint64 n) {
+  (void)fd;
+  (void)buf;
+  (void)n;
 #if 0
   int r;
   int todo=n>=65536?65536:n;
@@ -37,11 +40,15 @@ int64 writecb(int64 fd,const void* buf,uint64 n) {
 }
 
 int main(int argc,char* argv[]) {
+  (void)argc;
+  (void)argv;
+#if 0
   io_batch* b=iob_new(1234);
   int64 fd=open("t.c",0);
   iob_addbuf(b,"fnord",5);
   iob_addfile_close(b,fd,0,7365);
   iob_write(1,b,writecb);
+#endif
 #if 0
   char dest[1024];
   unsigned long len;
@@ -310,5 +317,19 @@ int main(int argc,char* argv[]) {
   rdtscl(c);
   printf("%lu %lu\n",b-a,c-b);
 #endif
+#if 0
+  unsigned long size;
+  char* buf=mmap_read(argv[1],&size);
+  if (buf) {
+    unsigned int x=fmt_urlencoded2(0,buf,size,"x");
+    unsigned int y;
+    char* tmp=malloc(x+1);
+    y=fmt_urlencoded2(tmp,buf,size,"x");
+    write(1,tmp,x);
+  }
+#endif
+  printf("%d %d\n",strcmp("foo","bar"),str_diff("foo","bar"));
+  printf("%d %d\n",strcmp("foo","ar"),str_diff("foo","ar"));
+  return 0;
 }
 
